@@ -65,6 +65,7 @@ type UpstreamConfig struct {
 	IdleTimeout        int  `yaml:"idle_timeout"`
 	MaxConns           int  `yaml:"max_conns"`
 	EnablePipeline     bool `yaml:"enable_pipeline"`
+	EnableHTTP3        bool `yaml:"enable_http3"`
 	InsecureSkipVerify bool `yaml:"insecure_skip_verify"`
 }
 
@@ -105,6 +106,7 @@ func newFastForward(bp *handler.BP, args *Args) (*fastForward, error) {
 			IdleTimeout:    time.Duration(c.IdleTimeout) * time.Second,
 			MaxConns:       c.MaxConns,
 			EnablePipeline: c.EnablePipeline,
+			EnableHTTP3:    c.EnableHTTP3,
 			TLSConfig: &tls.Config{
 				InsecureSkipVerify: c.InsecureSkipVerify,
 				RootCAs:            rootCAs,
